@@ -83,9 +83,6 @@ def _get_figures_and_axes(n, m, figsize):
         ax.plot(1, 0, ">k", transform=ax.get_yaxis_transform(), clip_on=False)
         ax.plot(0, 1, "^k", transform=ax.get_xaxis_transform(), clip_on=False)
 
-        ax.set_xlabel(r"$x$", fontsize=16, loc="right")
-        ax.set_ylabel(r"$y$", fontsize=16, loc="top", rotation="horizontal")
-
     return figs, axes
 
 
@@ -128,6 +125,50 @@ def _set_multiple_ticks(xmin, xmax, ymin, ymax, xstep, ystep, axes):
     return axes
 
 
+def annotate(xy, xytext, s, fontsize=20):
+    ax = plt.gca()
+    ax.annotate(
+        text=s,
+        xy=xy,
+        xytext=xytext,
+        fontsize=fontsize,
+        arrowprops=dict(
+            arrowstyle="->",
+            lw=2,
+            color="black",
+            alpha=0.7,
+            connectionstyle="arc3,rad=-0.3",
+        ),
+        bbox=dict(boxstyle="round,pad=0.4", fc="white", ec="black", lw=1.5),
+        horizontalalignment="left",
+        verticalalignment="center",
+    )
+
+
+def make_bar(xy, length, orientation):
+    x, y = xy
+
+    if orientation == "horizontal":
+        plt.annotate(
+            "",
+            xy=xy,
+            xycoords="data",
+            xytext=(x + length, y),
+            textcoords="data",
+            arrowprops=dict(arrowstyle="|-|,widthA=0.5,widthB=0.5", color="black"),
+        )
+
+    elif orientation == "vertical":
+        plt.annotate(
+            "",
+            xy=xy,
+            xycoords="data",
+            xytext=(x, y + length),
+            textcoords="data",
+            arrowprops=dict(arrowstyle="|-|,widthA=0.5,widthB=0.5", color="black"),
+        )
+
+
 def plot(
     functions,
     fn_labels=True,
@@ -144,12 +185,24 @@ def plot(
     domain=False,
     fontsize=20,
     figsize=None,
+    xlabel=None,
+    ylabel=None,
 ):
     fig, ax = _get_figure_and_axis()
 
     if figsize is not None:
         fig.set_size_inches(figsize)
 
+    if xlabel is None:
+        xlabel = r"$x$"
+
+    ax.set_xlabel(xlabel, fontsize=fontsize, loc="right")
+
+    if ylabel is None:
+        ylabel = r"$y$"
+
+    ax.set_ylabel(ylabel, fontsize=fontsize, loc="top", rotation="horizontal")
+
     if ticks:
         _set_ticks(
             xmin=xmin,
